@@ -11,7 +11,9 @@ OC.L10N.register(
     "Today" : "오늘",
     "Yesterday" : "어제",
     "This week" : "이번 주",
+    "Last week" : "저번 주",
     "This month" : "이번 달",
+    "Last month" : "저번 달",
     "Rename" : "이름 바꾸기",
     "Delete note" : "메모 삭제",
     "Remove from favorites" : "즐겨찾기에서 제거",
