@@ -1,8 +1,8 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "ئىزاھاتلار",
     "Error" : "خاتالىق",
+    "Notes" : "ئىزاھاتلار",
     "Settings" : "تەڭشەكلەر",
     "Today" : "بۈگۈن",
     "Rename" : "ئات ئۆزگەرت",
@@ -10,4 +10,4 @@ OC.L10N.register(
     "Add to favorites" : "Add to favorites",
     "Edit" : "تەھرىر"
 },
-"nplurals=1; plural=0;");
+"nplurals=2; plural=(n != 1);");
